@@ -95,7 +95,7 @@ _fig_pseudocolor (red, green, blue)
      int red, green, blue;
 #endif
 {
-  unsigned long int difference = MAXINT;
+  unsigned long int difference = INT_MAX;
   int i;
   int best = 0;
   
