@@ -1,23 +1,31 @@
 /* This file contains routines for creating, manipulating, and deleting a
    special sort of output buffer: an Outbuf.  They are invoked by drawing
    methods for Plotters that do not do real-time output.  Such Plotters
-   store the device code for each page of graphics in an Outbuf.  Bounding
-   box information may be stored in the Outbuf, along with device code.
+   store the device code for each page of graphics in an Outbuf.  Along
+   with a page of device code, an Outbuf optionally stores bounding box
+   information for the page.
 
-   Outbufs may be resized when they are too full.  The strange resizing
-   method (_UPDATE_BUFFER) is needed because on many systems, sprintf()
-   does not return the number of characters it writes.
+   Outbufs are resized when they are too full.  The strange resizing method
+   (_UPDATE_BUFFER) is needed because on many systems, sprintf() does not
+   return the number of characters it writes.  _UPDATE_BUFFER is called
+   after each call to sprintf(); it is not invoked automatically.
    
    Output buffers of this sort are a bit of a kludge.  They may eventually
    be replaced or supplemented by an in-core object hierarchy, which
-   deletepl() will scan. */
+   deletepl() will scan.
+
+   When erase() is invoked on the Plotter, _RESET_OUTBUF is called, to
+   remove all graphics from the Outbuf.  There is provision for keeping a
+   section of initialization code in the Outbuf, untouched.  This is
+   arranged by a previous call to _FREEZE_OUTBUF.  Anything in the Outbuf
+   at that time will be untouched by a later call to _RESET_OUTBUF. */
 
 #include "sys-defines.h"
 #include "plot.h"
 #include "extern.h"
 
 /* initial length for an Outbuf (should be large enough to handle any
-   single one of our sprintf's without overflow). */
+   single one of our sprintf's [including final NUL] without overflow). */
 #define INITIAL_OUTBUF_LEN 256
 
 Outbuf *
@@ -31,15 +39,12 @@ _new_outbuf ()
 
   bufp = (Outbuf *)_plot_xmalloc(sizeof(Outbuf));
   bufp->base = (char *)_plot_xmalloc(INITIAL_OUTBUF_LEN * sizeof(char));
-  bufp->len = INITIAL_OUTBUF_LEN;
-  bufp->point = bufp->base;
-  bufp->contents = 0;
+  bufp->len = (unsigned long)INITIAL_OUTBUF_LEN;
   bufp->next = NULL;
-  bufp->xrange_min = DBL_MAX;
-  bufp->xrange_max = -(DBL_MAX);
-  bufp->yrange_min = DBL_MAX;
-  bufp->yrange_max = -(DBL_MAX);
-  *(bufp->base) = '\0';
+  bufp->reset_point = bufp->base;
+  bufp->reset_contents = (unsigned long)0L;
+  _reset_outbuf (bufp);
+
   return bufp;
 }
 
@@ -51,13 +56,26 @@ _reset_outbuf (bufp)
      Outbuf *bufp;
 #endif
 {
-  bufp->point = bufp->base;
-  bufp->contents = 0;
+  *(bufp->reset_point) = '\0';
+  bufp->point = bufp->reset_point;
+  bufp->contents = bufp->reset_contents;
+
   bufp->xrange_min = DBL_MAX;
   bufp->xrange_max = -(DBL_MAX);
   bufp->yrange_min = DBL_MAX;
   bufp->yrange_max = -(DBL_MAX);
-  *(bufp->base) = '\0';
+}
+
+void
+#ifdef _HAVE_PROTOS
+_freeze_outbuf (Outbuf *bufp)
+#else
+_freeze_outbuf (bufp)
+     Outbuf *bufp;
+#endif
+{
+  bufp->reset_point = bufp->point;
+  bufp->reset_contents = bufp->contents;
 }
 
 void
@@ -75,8 +93,8 @@ _delete_outbuf (bufp)
     }
 }
 
-/* UPDATE_BUFFER is called after each sprintf() and other object write
-   operations */
+/* UPDATE_BUFFER is called manually, after each sprintf() and other object
+   write operations */
 void
 #ifdef _HAVE_PROTOS
 _update_buffer (Outbuf *bufp)
@@ -87,21 +105,24 @@ _update_buffer (bufp)
 {
   int additional;
 
+  /* determine how many add'l chars were added */
   additional = strlen (bufp->point);
   bufp->point += additional;
   bufp->contents += additional;
-
-  if (bufp->contents > bufp->len - 1) /* need room for NUL */
+  
+  if (bufp->contents + 1 > bufp->len) /* need room for NUL */
     {
       fprintf (stderr, "libplot: output buffer overrun\n");
       exit (1);
     }
-  if (bufp->contents > bufp->len / 2)
+  if (bufp->contents > (bufp->len >> 1))
+    /* expand buffer */
     {
       bufp->base = 
 	(char *)_plot_xrealloc (bufp->base, 2 * bufp->len * sizeof(char));
       bufp->len *= 2;
       bufp->point = bufp->base + bufp->contents;
+      bufp->reset_point = bufp->base + bufp->reset_contents;
     }      
 }
 
