@@ -6,16 +6,19 @@
    state. */
 
 /* This is a generic method.  Some types of Plotter may do something else.
-   E.g., Fig Plotters invoke this, and if the retrieved font is a
-   Postscript font, quantizes the size (see f_retrieve.c).  X and X Drawable
-   Plotters have their own retrieval method and don't invoke this at all
-   (see x_retrieve.c). */
+   E.g., a Fig Plotter invokes this, and if the retrieved font is a
+   Postscript font, quantizes the size (see f_retrieve.c).  X and X
+   Drawable Plotters have their own retrieval method and don't invoke this
+   at all (see x_retrieve.c). */
 
 #include "sys-defines.h"
 #include "plot.h"
 #include "extern.h"
 #include "g_her_metr.h"
 
+static bool _match_ps_font __P ((void));
+static bool _match_pcl_font __P ((void));
+
 void
 #ifdef _HAVE_PROTOS
 _g_retrieve_font(void)
@@ -29,6 +32,7 @@ _g_retrieve_font()
   /* try to match user-specified font name */
 
   if (_plotter->have_hershey_fonts)
+    /* should always be true... */
     {
       /* is font a vector font? */
       i = -1;
@@ -60,68 +64,29 @@ _g_retrieve_font()
 	} 
     }
 
-  if (_plotter->have_ps_fonts)
+  /* Try to match the font name with the name of a PCL font or a PS font.
+     However there is a namespace collision: "Courier" etc. and "Symbol"
+     occur on both lists.  So which list we search first depends on what
+     type of Plotter we have. */
+
+  switch (_plotter->type)
     {
-      /* is font a PS font? */
-      i = -1;
-      while (_ps_font_info[++i].ps_name)
-	{
-	  if (strcasecmp (_ps_font_info[i].ps_name, 
-			  _plotter->drawstate->font_name) == 0
-	      || strcasecmp (_ps_font_info[i].x_name, 
-			     _plotter->drawstate->font_name) == 0
-	      /* try alternative X font name if any */
-	      || (_ps_font_info[i].x_name_alt != NULL
-		  && strcasecmp (_ps_font_info[i].x_name_alt,
-				 _plotter->drawstate->font_name) == 0))
-	    {
-	      _plotter->drawstate->font_type = F_POSTSCRIPT;
-	      _plotter->drawstate->typeface_index = 
-		_ps_font_info[i].typeface_index;
-	      _plotter->drawstate->font_index = 
-		_ps_font_info[i].font_index;
-	      _plotter->drawstate->font_is_iso8859_1 = 
-		_ps_font_info[i].iso8859_1;
-	      _plotter->drawstate->true_font_size = 
-		_plotter->drawstate->font_size;
-	      _plotter->drawstate->font_ascent 
-		= _plotter->drawstate->true_font_size
-		  * (double)(_ps_font_info[i].font_ascent)/1000.0;
-	      _plotter->drawstate->font_descent 
-		= _plotter->drawstate->true_font_size
-		  * (double)(_ps_font_info[i].font_descent)/1000.0;
-	      return;
-	    }
-	}
-    }
-  
-  if (_plotter->have_pcl_fonts)
-    {
-      /* is font a PCL font? */
-      i = -1;
-      while (_pcl_font_info[++i].ps_name)
-	{
-	  if (strcasecmp (_pcl_font_info[i].ps_name, 
-			  _plotter->drawstate->font_name) == 0)
-	    {
-	      _plotter->drawstate->font_type = F_PCL;
-	      _plotter->drawstate->typeface_index = 
-		_pcl_font_info[i].typeface_index;
-	      _plotter->drawstate->font_index = 
-		_pcl_font_info[i].font_index;
-	      _plotter->drawstate->font_is_iso8859_1 = 
-		_pcl_font_info[i].iso8859_1;
-	      _plotter->drawstate->true_font_size = 
-		_plotter->drawstate->font_size;
-	      _plotter->drawstate->font_ascent 
-		= _plotter->drawstate->true_font_size
-		  * (double)(_pcl_font_info[i].font_ascent)/1000.0;
-	      _plotter->drawstate->font_descent 
-		= _plotter->drawstate->true_font_size
-		  * (double)(_pcl_font_info[i].font_descent)/1000.0;
-	      return;
-	    }
-	}
+    case PL_PS:
+    default:
+      /* search PS font list first */
+      if (_plotter->have_ps_fonts && _match_ps_font())
+	return;
+      if (_plotter->have_pcl_fonts && _match_pcl_font())
+	return;
+      break;
+    case PL_HPGL:
+    case PL_PCL:
+      /* search PCL font list first */      
+      if (_plotter->have_pcl_fonts && _match_pcl_font())
+	return;
+      if (_plotter->have_ps_fonts && _match_ps_font())
+	return;
+      break;
     }
 
   if (_plotter->have_stick_fonts)
@@ -180,3 +145,88 @@ _g_retrieve_font()
   
   return;
 }
+
+static bool
+#ifdef _HAVE_PROTOS
+_match_pcl_font (void)
+#else
+_match_pcl_font ()
+#endif
+{
+  int i = -1;
+
+  /* is font a PCL font? */
+  while (_pcl_font_info[++i].ps_name)
+    {
+      if (strcasecmp (_pcl_font_info[i].ps_name, 
+		      _plotter->drawstate->font_name) == 0)
+	{
+	  _plotter->drawstate->font_type = F_PCL;
+	  _plotter->drawstate->typeface_index = 
+	    _pcl_font_info[i].typeface_index;
+	  _plotter->drawstate->font_index = 
+	    _pcl_font_info[i].font_index;
+	  _plotter->drawstate->font_is_iso8859_1 = 
+	    _pcl_font_info[i].iso8859_1;
+	  _plotter->drawstate->true_font_size = 
+	    _plotter->drawstate->font_size;
+	  _plotter->drawstate->font_ascent 
+	    = _plotter->drawstate->true_font_size
+	      * (double)(_pcl_font_info[i].font_ascent)/1000.0;
+	  _plotter->drawstate->font_descent 
+	    = _plotter->drawstate->true_font_size
+	      * (double)(_pcl_font_info[i].font_descent)/1000.0;
+	  return true;
+	}
+    }
+  
+  return false;
+}
+
+
+static bool
+#ifdef _HAVE_PROTOS
+_match_ps_font (void)
+#else
+_match_ps_font ()
+#endif
+{
+  int i = -1;
+
+  /* is font a PS font? */
+  while (_ps_font_info[++i].ps_name)
+    {
+      if (strcasecmp (_ps_font_info[i].ps_name, 
+		      _plotter->drawstate->font_name) == 0
+	  /* try alternative PS font name if any */
+	  || (_ps_font_info[i].ps_name_alt != NULL
+	      && strcasecmp (_ps_font_info[i].ps_name_alt, 
+			     _plotter->drawstate->font_name) == 0)
+	  || strcasecmp (_ps_font_info[i].x_name, 
+			 _plotter->drawstate->font_name) == 0
+	  /* try alternative X font name if any */
+	  || (_ps_font_info[i].x_name_alt != NULL
+	      && strcasecmp (_ps_font_info[i].x_name_alt,
+			     _plotter->drawstate->font_name) == 0))
+	{
+	  _plotter->drawstate->font_type = F_POSTSCRIPT;
+	  _plotter->drawstate->typeface_index = 
+	    _ps_font_info[i].typeface_index;
+	  _plotter->drawstate->font_index = 
+	    _ps_font_info[i].font_index;
+	  _plotter->drawstate->font_is_iso8859_1 = 
+	    _ps_font_info[i].iso8859_1;
+	  _plotter->drawstate->true_font_size = 
+	    _plotter->drawstate->font_size;
+	  _plotter->drawstate->font_ascent 
+	    = _plotter->drawstate->true_font_size
+	      * (double)(_ps_font_info[i].font_ascent)/1000.0;
+	  _plotter->drawstate->font_descent 
+	    = _plotter->drawstate->true_font_size
+	      * (double)(_ps_font_info[i].font_descent)/1000.0;
+	  return true;
+	}
+    }
+  
+  return false;
+}
