@@ -1,6 +1,9 @@
 /* This file contains the openpl method, which is a standard part of
    libplot.  It opens a Plotter object. */
 
+/* This version is for Tek Plotters.  We emit terminal initialization
+   codes, depending on the Tektronix type. */
+
 #include "sys-defines.h"
 #include "plot.h"
 #include "extern.h"
@@ -12,35 +15,12 @@ _t_openpl (void)
 _t_openpl ()
 #endif
 {
-  const char* term_type;
-
   if (_plotter->open)
     {
       _plotter->error ("openpl: invalid operation");
       return -1;
     }
 
-  /* initialize data members from values of relevant class variables */
-
-  term_type = (const char *)_get_plot_param ("TERM");
-  if (term_type != NULL)
-    {
-      if ((strcmp (term_type, "xterm") == 0)
-	  || (strcmp (term_type, "xterms") == 0)
-	  || (strcmp (term_type, "kterm") == 0))
-	_plotter->display_type = D_XTERM;
-      else if ((strcmp (term_type, "ansi.sys") == 0)
-	       || (strcmp (term_type, "ansi.sysk") == 0)
-	       || (strcmp (term_type, "ansisys") == 0)
-	       || (strcmp (term_type, "ansisysk") == 0)
-	       || (strcmp (term_type, "kermit") == 0))
-	_plotter->display_type = D_KERMIT;
-      else
-	_plotter->display_type = D_GENERIC;
-    }
-  else
-    _plotter->display_type = D_GENERIC;
-  
   /* flag device as open */
   _plotter->open = true;
   _plotter->opened = true;
